.. include:: references.txt

.. image:: _static/gammapy_banner.png
    :width: 400px


**Gammapy** is an open source (BSD licensed) gamma-ray astronomy Python package.

It is an in-development `affiliated package <http://www.astropy.org/affiliated/index.html>`__ of `Astropy <http://www.astropy.org/>`__ 
that builds on the core `scientific Python stack <http://www.scipy.org/about.html>`__ to provide tools to simulate and analyse
the gamma-ray sky for telescopes such as `Fermi <http://fermi.gsfc.nasa.gov/>`__, `H.E.S.S. <http://www.mpi-hd.mpg.de/hfm/HESS/>`__
and `CTA <https://www.cta-observatory.org/>`__.

Currently the functionality is limited and geared towards Galactic plane survey studies,
but the idea is that Gammapy is a place to share and collaborate for gamma-ray astronomy Pythonistas
... contributions welcome! 

* Read the `Gammapy documentation`_.
* Ask questions on the `Gammapy mailing list`_.
* Request features, report bugs or contribute on the `Gammapy GitHub page`_.
* Check out the `Gammapy project summary on Ohloh`_ or the `Gammapy page on PyPI`_.
* Requires Python (version 2.7 and 3.3 or later), Numpy (version 1.6 or later) and Astropy (version 0.4 or later)

General documentation
---------------------

.. toctree::
  :maxdepth: 1

  install
  introduction
  scripts/index
  tutorials/index
  dataformats/index
  references
  credit
  development/index

The Gammapy toolbox
-------------------

.. toctree::
  :maxdepth: 1
 
  astro/index
  background/index
  catalog/index
  data/index
  datasets/index
  detect/index
  image/index
  irf/index
  morphology/index
  obs/index
  shower/index
  spectrum/index
  stats/index
  utils/index
